import React, { useEffect, useState } from 'react'
import { Form, Input, Modal } from 'antd';
import dictService from '@/request/service/template-dict';
import { useRequest } from '@/hooks/use-request';
import type { DataDictVO } from '@/models'
import { antdUtils } from '@/utils/antd';

const layout = {
    labelCol: { span: 4, },
    wrapperCol: { span: 16 },
};

export default (props: {
    visible: boolean;
    onCancel: (flag?: boolean) => void;
    onSave: (role: DataDictVO) => void;
    data?: DataDictVO | null;
}) => {

    const { visible, onCancel, onSave, data } = props;

    const { runAsync: updateApi } = useRequest(dictService.updateDictApi, { manual: true });
    const { runAsync: createApi } = useRequest(dictService.createDictApi, { manual: true });

    const isEdit = !!data;


    const [saveLoading, setSaveLoading] = useState(false);
    const [form] = Form.useForm();

    useEffect(() => {
        if (visible) {
            if (data) {
                form.setFieldsValue(data);
            }
        } else {
            form.resetFields();
        }
    }, [visible]);

    const save = async () => {
        setSaveLoading(true);
        const fieldValues = form.getFieldsValue();
        const newValue = isEdit ? { ...data, ...fieldValues } : fieldValues;
        const [error, { msg, code }] = isEdit ? await updateApi(newValue) : await createApi(newValue);
        if (!error && code === 0) {
            onSave(newValue);
        } else {
            antdUtils.message?.open({
                type: 'error',
                content: msg ?? '操作失败',
            });
        }
        setSaveLoading(false);
    }

    return (
        <>
            <Modal
                open={visible}
                title="新建"
                width={640}
                onOk={save}
                onCancel={() => onCancel()}
                confirmLoading= {saveLoading}
                destroyOnClose
            >
                <Form
                    form={form}
                    {...layout}
                    onFinish={save}
                    labelCol={{ flex: '0 0 100px' }}
                    wrapperCol={{ span: 16 }}
                >
                    <Form.Item name="name" label="字典名称"
                        rules={[
                            {
                                required: true,
                                message: '请输字典名称',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="description" label="字典描述"
                        rules={[
                            {
                                required: true,
                                message: '请输入字典描述',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>
                </Form>
            </Modal>
        </>
    )
};
