import request from '@/request';
import { TenantPageReqVO, TenantVO, TenantExportReqVO, PageData } from '@/models';

const BASE_URL = '/admin-api/system/tenant';

export default {
    // 查询租户列表
    getTenantPageApi: (params: TenantPageReqVO) => {
        return request.get<PageData<TenantVO>>(`${BASE_URL}/page`, { params })
    },

    // 查询租户详情
    getTenantApi: (id: number) => {
        return request.get(`${BASE_URL}/get?id=${id}`)
    },

    // 新增租户
    createTenantApi: (data: TenantVO) => {
        return request.post(`${BASE_URL}/create`, data)
    },

    // 修改租户
    updateTenantApi: (data: TenantVO) => {
        return request.put(`${BASE_URL}/update`, data)
    },

    // 删除租户
    deleteTenantApi: (id: number) => {
        return request.delete(`${BASE_URL}/delete?id=${id}`)
    },

    // 导出租户
    exportTenantApi: (params: TenantExportReqVO) => {
        return request.get(`${BASE_URL}/export-excel`, { params, responseType: 'blob'})
    },

}


